==> asset.visuretech.com_v5.1.zip: resources/lang/ml-IN/admin/categories/general.php <==
<?php

return array(
    'asset_categories' 					=> 'Asset Categories',
    'category_name'  					=> 'വിഭാഗത്തിന്റെ പേര്',
    'checkin_email'                     => 'Send email to user on checkin/checkout.',
    'checkin_email_notification'        => 'This user will be sent an email on checkin/checkout.',
    'clone'                             => 'Clone Category',
    'create'  							=> 'വിഭാഗം ഉണ്ടാകുക',
    'edit'                              => 'വിഭാഗം എഡിറ്റു ചെയ്യുക',
    'eula_text'							=> 'വിഭാഗം EULA',
    'eula_text_help'					=> 'This field allows you to customize your EULAs for specific types of assets. If you only have one EULA for all of your assets, you can check the box below to use the primary default.',
    'name'                              => 'Category Name',
    'require_acceptance'				=> 'Require users to confirm acceptance of assets in this category.',
    'required_acceptance'				=> 'This user will be emailed with a link to confirm acceptance of this item.',
    'required_eula'						=> 'This user will be emailed a copy of the EULA',
    'no_default_eula'					=> 'No primary default EULA found. Add one in Settings.',
    'update'  							=> 'Update Category',
    'use_default_eula'					=> 'Use the <a href="#" data-toggle="modal" data-target="#eulaModal">primary default EULA</a> instead.',
    'use_default_eula_disabled'			=> '<del>Use the primary default EULA instead.</del> No primary default EULA is set. Please add one in Settings.',
    'use_default_eula_column'			=> 'Use default EULA',

);

==> asset.visuretech.com-8.1.zip: resources/lang/ml-IN/admin/categories/general.php <==
<?php

return array(
    'asset_categories' 					=> 'Asset Categories',
    'category_name'  					=> 'വിഭാഗത്തിന്റെ പേര്',
    'checkin_email'                     => 'Send email to user on checkin/checkout.',
    'email_to_initiator'                => 'Send email to you when user accepts or declines checkout.',
    'checkin_email_notification'        => 'This user will be sent an email on checkin/checkout.',
    'clone'                             => 'Clone Category',
    'create'  							=> 'വിഭാഗം ഉണ്ടാകുക',
    'edit'                              => 'വിഭാഗം എഡിറ്റു ചെയ്യുക',
    'email_will_be_sent_due_to_global_eula' => 'An email will be sent to the user because the global EULA is being used.',
    'email_will_be_sent_due_to_category_eula' => 'An email will be sent to the user because a EULA is set for this category.',
    'eula_text'							=> 'വിഭാഗം EULA',
    'eula_text_help'					=> 'This field allows you to customize your EULAs for specific types of assets. If you only have one EULA for all of your assets, you can check the box below to use the primary default.',
    'name'                              => 'വിഭാഗത്തിന്റെ പേര്',
    'require_acceptance'				=> 'Require users to confirm acceptance of assets in this category.',
    'required_acceptance'				=> 'This user will be emailed with a link to confirm acceptance of this item.',
    'required_eula'						=> 'This user will be emailed a copy of the EULA',
    'no_default_eula'					=> 'No primary default EULA found. Add one in Settings.',
    'update'  							=> 'Update Category',
    'use_default_eula'					=> 'Use the <a href="#" data-toggle="modal" data-target="#eulaModal">primary default EULA</a> instead.',
    'use_default_eula_disabled'			=> '<del>Use the primary default EULA instead.</del> No primary default EULA is set. Please add one in Settings.',
    'use_default_eula_column'			=> 'Use default EULA',
    'import_require_acceptance'         => 'Require Acceptance',
    'import_checkin_email'              => 'Send Checkin Email',
    'import_eula_text'                  => 'EULA text',
    'import_category_type'              => 'Category Type',

);
